@@ -23,8 +23,6 @@
 #'   considered.
 #' @param nkeep An integer, or NULL. If given, only the `nkeep` most likely
 #'   pairings are kept for each victim.
-#' @param check A logical indicating if the input data should be checked for
-#'   consistency. Default: TRUE.
 #' @param numCores An integer; the number of cores used in parallelisation.
 #'   Default: 1.
 #' @param verbose A logical. Default: TRUE.
@@ -59,8 +57,7 @@
 #' @export
 findUndisputed = function(dvi, pairings = NULL, ignoreSex = FALSE, 
                           threshold = 10000, strict = FALSE, relax = !strict, 
-                          limit = 0, nkeep = NULL, check = TRUE, numCores = 1, 
-                          verbose = TRUE) {
+                          limit = 0, nkeep = NULL, numCores = 1, verbose = TRUE) {
   
   if(!missing(relax)) {
     cat("Warning: `relax` is deprecated; replaced by (its negation) `strict`")
@@ -68,10 +65,13 @@ findUndisputed = function(dvi, pairings = NULL, ignoreSex = FALSE,
   }
   
   if(verbose) {
-    cat("\nFinding undisputed matches\n")
+    cat("Finding undisputed matches\n")
     cat("Pairwise LR threshold =", threshold, "\n")
   }
 
+  if(!isTRUE(length(threshold) == 1 && threshold >= 0))
+    stop2("`treshold` must be a nonnegative number: ", threshold %||% "NULL")
+  
   # Ensure proper dviData object
   dvi = consolidateDVI(dvi)
   
@@ -100,40 +100,25 @@ findUndisputed = function(dvi, pairings = NULL, ignoreSex = FALSE,
     missing = dvi$missing
     
     # Pairwise LR matrix
-    ss = pairwiseLR(dvi, check = check, limit = limit, nkeep = nkeep, 
-                    numCores = numCores, verbose = verbose)
+    ss = pairwiseLR(dvi, limit = limit, nkeep = nkeep, numCores = numCores, 
+                    check = FALSE, verbose = verbose)
     B = ss$LRmatrix
     
-    # Indices of matches exceeding threshold
-    highIdx = which(B > threshold, arr.ind = TRUE)
+    # Indices of undisputed matches
+    undisp = undisputedEntries(B, threshold, strict = strict)
+    nu = nrow(undisp)
     
-    if(strict) { # undisputed = no others in row/column exceed 1
-      goodRows = which(rowSums(B <= 1) == ncol(B) - 1)
-      goodCols = which(colSums(B <= 1) == nrow(B) - 1)
-      isUndisp = highIdx[, "row"] %in% goodRows & highIdx[, "col"] %in% goodCols
-    }
-    else { # undisputed = no others in row/column exceed LR/threshold
-      isUndisp = sapply(seq_len(nrow(highIdx)), function(k) {  # safer than apply(.., 1)!
-        rw = highIdx[k,1]
-        cl = highIdx[k,2]
-        all(c(B[rw, -cl], B[-rw, cl]) <= B[rw, cl]/threshold)
-      })
-    }
-     
-    Nundisp = if(!length(isUndisp)) 0 else sum(isUndisp)
-    
-    if(!Nundisp) {
-      if(verbose)
+    if(verbose) {
+      if(nu == 0) 
         cat(sprintf("No%s undisputed matches\n", if(stp > 1) " further" else ""))
-      break
+      else 
+        cat(sprintf("%d undisputed match%s\n", nu, if(nu == 1) "" else "es"))
     }
     
-    if(verbose)
-      cat(sprintf("%d undisputed match%s\n", Nundisp, if(Nundisp == 1) "" else "es"))
+    if(nu == 0)
+      break
     
-    undisp = highIdx[isUndisp, , drop = FALSE]
-    
-    for(i in seq_len(Nundisp)) {
+    for(i in seq_len(nu)) {
       rw = undisp[i,1]
       cl = undisp[i,2]
       vic = vics[rw] 
@@ -172,7 +157,7 @@ findUndisputed = function(dvi, pairings = NULL, ignoreSex = FALSE,
     summary$Sample = names(RES)
     summary$Family = comp[summary$Missing]
     summary$Conclusion = "Undisputed"
-    summary$Comment = paste("step", summary$Step)
+    summary$Comment = paste("Step", summary$Step)
     summary = summary[c("Family", "Missing", "Sample", "LR", "Conclusion", "Comment")]
     rownames(summary) = NULL
   }
